@@ -13,6 +13,8 @@ type Addition struct {
 	DownloadAPI    string `json:"download_api" type:"select" options:"official,crack" default:"official"`
 	ClientID       string `json:"client_id" required:"true" default:"iYCeC9g08h5vuP9UqvPHKKSVrKFXGa1v"`
 	ClientSecret   string `json:"client_secret" required:"true" default:"jXiFMOPVPCWlO2M5CwWQzffpNPaGTRBG"`
+	CustomCrackUA  string `json:"custom_crack_ua" required:"true" default:"netdisk"`
+	AccessToken    string
 }
 
 var config = driver.Config{
