@@ -22,12 +22,17 @@ var once sync.Once
 
 func (d *LanZou) doupload(callback base.ReqCallback, resp interface{}) ([]byte, error) {
 	return d.post(d.BaseUrl+"/doupload.php", func(req *resty.Request) {
-		req.SetQueryParam("uid", d.uid)
-		callback(req)
+		req.SetQueryParams(map[string]string{
+			"uid": d.uid,
+			"vei": d.vei,
+		})
+		if callback != nil {
+			callback(req)
+		}
 	}, resp)
 }
 
-func (d *LanZou) get(url string, callback base.ReqCallback, resp interface{}) ([]byte, error) {
+func (d *LanZou) get(url string, callback base.ReqCallback) ([]byte, error) {
 	return d.request(url, http.MethodGet, callback, false)
 }
 
@@ -224,7 +229,7 @@ func (d *LanZou) getShareUrlHtml(shareID string) (string, error) {
 						Value: vs,
 					})
 				}
-			}, nil)
+			})
 		if err != nil {
 			return "", err
 		}
@@ -315,7 +320,7 @@ func (d *LanZou) getFilesByShareUrl(shareID, pwd string, sharePageData string) (
 			log.Errorf("lanzou: err => not find file page param ,data => %s\n", sharePageData)
 			return nil, fmt.Errorf("not find file page param")
 		}
-		data, err := d.get(fmt.Sprint(d.ShareUrl, urlpaths[1]), nil, nil)
+		data, err := d.get(fmt.Sprint(d.ShareUrl, urlpaths[1]), nil)
 		if err != nil {
 			return nil, err
 		}
@@ -445,3 +450,22 @@ func (d *LanZou) getFileRealInfo(downURL string) (*int64, *time.Time) {
 	size, _ := strconv.ParseInt(res.Header().Get("Content-Length"), 10, 64)
 	return &size, &time
 }
+
+func (d *LanZou) getVei() (string, error) {
+	resp, err := d.get("https://pc.woozooo.com/mydisk.php", func(req *resty.Request) {
+		req.SetQueryParams(map[string]string{
+			"item":   "files",
+			"action": "index",
+			"u":      d.uid,
+		})
+	})
+	if err != nil {
+		return "", err
+	}
+	html := RemoveNotes(string(resp))
+	data, err := htmlJsonToMap(html)
+	if err != nil {
+		return "", err
+	}
+	return data["vei"], nil
+}
